Prepare spline parameters object for BT-SPAS-X model

build_spline_data(number_weeks_catch, k_int)

Arguments

number_weeks_catch

number of weeks with catch data.

k_int

number of knots to use in building spline for abundance data. Rule of thumb is 1 knot for every 4 data points for a cubic spline (which has 4 parameters)

Value

a named list containing K and b_spline_matrix for passing to WinBUGS

Details

This function is called within run_single_bt_spas_x() and prepares spline parameters to pass to the data list