This function fits the Passage to Spawner (fit_passage_to_spawner_model()) for a given stream to all environmental covariates. For a stream, the dataset is truncated to only include years for which all environmental covariates are available. Parameters that are helpful for selecting a covariate are: R2_data, R2_fixed, mean_redds_per_spawner, b1_survival, sigma_redds_per_spawner, and spawner_abundance_forecast.

compare_P2S_model_covariates(stream)

Value

A table containing the following variables:

  • parameter Parameter name

  • mean Mean of the posterior distribution for a parameter

  • se_mean Monte Carlo standard error for summary of all chains merged (see details)

  • sd Standard deviation of the posterior distribution for a parameter

  • 2.5 2.5% quantile of posterior distribution for a parameter.

  • 25 25% quantile of posterior distribution for a parameter.

  • 50 50% quantile of posterior distribution for a parameter.

  • 7% 75% quantile of posterior distribution for a parameter.

  • 97.5 97.5% quantile of posterior distribution for a parameter.

  • n_eff Effective sample size for a parameter

  • Rhat Split Rhats for a parameter

  • year Year observed data came from