This function takes in a STAN fit object produced by running fit_passage_to_spawner_model() and produces a formatted table of parameter estimates from the Passage to Spawner model.

extract_P2S_estimates(p2s_inputs, passage_to_spawner_model_object)

Value

a table with the following variables:

  • parameter Parameter name

  • mean Mean of the posterior distribution for a parameter

  • se_mean Monte Carlo standard error for summary of all chains merged (see details)

  • sd Standard deviation of the posterior distribution for a parameter

  • 2.5 2.5% quantile of posterior distribution for a parameter.

  • 25 25% quantile of posterior distribution for a parameter.

  • 50 50% quantile of posterior distribution for a parameter.

  • 7% 75% quantile of posterior distribution for a parameter.

  • 97.5 97.5% quantile of posterior distribution for a parameter.

  • n_eff Effective sample size for a parameter

  • Rhat Split Rhats for a parameter

  • year Year observed data came from