Extract parameter estimates from abundance BUGS model object

extract_abundance_estimates(abundance_inputs, model_object)

Arguments

abundance_inputs

a list of inputs for the abundance BUGS model, generated by running prepare_abundance_inputs()

model_object

the BUGS object produced by running fit_abundance_model_BUGS().

site

the site fit.

run_year

the run year fit.

Value

A table with the format:

  • model_name

  • site

  • run_year

  • week_fit

  • location_fit

  • parameter

  • statistic

  • value

  • srjpedata_version

Details

This function extracts parameter estimates from the abundance BUGS model and returns them in a tidy data frame format.