This function takes in a STAN fit object produced by running fit_stock_recruit_model() and produces a formatted table of parameter estimates.

extract_stock_recruit_estimates(
  stock_recruit_inputs,
  stock_recruit_model_object
)

Arguments

stock_recruit_inputs

a named list produced by running prepare_stock_recruit_inputs()

stock_recruit_model_object

a STANfit object produced by running fit_stock_recruit_model()

Value

a table with the following variables:

  • parameter Parameter name

  • mean Mean of the posterior distribution for a parameter

  • se_mean Monte Carlo standard error for summary of all chains merged (see details)

  • sd Standard deviation of the posterior distribution for a parameter

  • 2.5 2.5% quantile of posterior distribution for a parameter.

  • 25 25% quantile of posterior distribution for a parameter.

  • 50 50% quantile of posterior distribution for a parameter.

  • 7% 75% quantile of posterior distribution for a parameter.

  • 97.5 97.5% quantile of posterior distribution for a parameter.

  • n_eff Effective sample size for a parameter

  • Rhat Split Rhats for a parameter

  • year Year observed data came from

Details

This function extracts parameter estimates from the stock recruit model object.