Extract parameter estimates from the survival STAN model object

extract_survival_estimates(model_object)

Arguments

model_object

the STAN object produced by running fit_survival_model().

Value

A table with the format:

  • parameter

  • year

  • reach_name

  • release_group

  • statistic

  • value

  • srjpedata_version

Details

This function extracts parameter estimates from the survival STAN model and returns them in a tidy data frame format.