Fit pCap model

fit_pCap_model(input)

Arguments

input

A list containing the inputs for the pCap model.

Value

a STANfit object with the pCap model fit.

Details

This function prepares the data list for the abundance STAN model based on what the model name is.