Diagnostic plots

generate_diagnostic_plot(inputs, fit)

Arguments

inputs

inputs for the fit model, created by running the appropriate prepare_inputs function.

fit

the model fit

model_results_name

The model type name associated with options in the database: either all_mark_recap, no_mark_recap, missing_mark_recap, no_mark_recap_no_trib, pcap_all, pcap_mainstem, p2s, or stock_recruit.

Value

Generates a diagnostic posterior predictive plot for a model fit.

Details

This function produces a posterior predictive check plot.