BT SPAS X diagnostic plots

generate_diagnostic_plot_juv(inputs, results_df)

Arguments

inputs

a list of inputs generated by running prepare_abundance_inputs()

results_df

a table of parameter estimates generated by running extract_abundance_estimates() or by pulling and filtering from the database using get_most_recent_model_results().

Value

A plot.

Details

This function produces a plot with data and results of fitting the pCap and abundance models for a given site and run year.