Stock-recruit diagnostic plots

generate_diagnostic_plot_sr(sr_inputs, sr_fit)

Arguments

sr_inputs

inputs for the fit model, created by running prepare_stock_recruit_inputs()

sr_fit

the model fit object, created by running fit_stock_recruit_model()

Value

A plot.

Details

This function produces a plot with observed spawner and estimated recruitment data, alongside predicted recruitment across a range of spawning stock sizes produced using posterior estimates from the model fit. It is meant to compare predicted and observed recruitment as a function of spawning stock.