This function produces a plot of observed and predicted abundance using posterior summaries retrieved from the database.

generate_results_plot_inseason(inseason_inputs, con)

Arguments

con

A database connection object.

forecast_inputs

A list with forecast metadata and inputs, including For_ewk and calendar labels.

Value

A ggplot object.