P2S results plots

generate_results_plot_p2s(p2s_inputs, con)

Arguments

p2s_inputs

inputs for the fit model, created by running prepare_P2S_inputs()

con

a connection to the database.

Value

A plot showing observed and predicted spawners by year.

Details

This function produces a plot with predicted spawners with uncertainty. for simple comparison.