Stock-recruit results plots

generate_results_plot_sr(sr_inputs, con)

Arguments

sr_inputs

inputs for the fit model, created by running prepare_stock_recruit_inputs()

con

a connection to the database.

Value

A plot.

Details

This function produces a plot with observed and predicted recruits for simple comparison.