Creates a pin board for model data storage in Azure Blob Storage.

model_pin_board(storage_account, container, model_name, ...)

Arguments

storage_account

The name of the Azure Storage account.

container

The name of the blob container within the storage account.

...

Additional arguments passed to setup_azure_blob_backend().

Value

A pins board object connected to the specified Azure Blob Storage container.

Examples

if (FALSE) { # \dontrun{
board <- model_pin_board("my_storage_account", "my_container")
} # }