Prepare mainstem inputs for abundance model

prepare_mainstem_pCap_data(mainstem_site)

Arguments

mainstem_site

site on the mainstem Sacramento River (either knights landing, tisdale, or red bluff diversion dam) for which you want to prepare inputs

Value

a named list, with each element containing the inputs required for one of the three mainstem sites. In this named list are

  • inputs a list of data and inits for input into the abundance model.

  • sites_fit The site the inputs were prepared for (either knights landing, tisdale, or red bluff diversion dam).

Details

This function is called within prepare_pCap_inputs()