Creates an AzureStor storage container object to be used by the pins package.

setup_azure_blob_backend(
  storage_account,
  access_key = Sys.getenv("AZ_CONTAINER_ACCESS_KEY")
)

Arguments

storage_account

string storage account to create connection to

access_key

the access key that provides for the blob access. By default an env variable with the name AZ_CONTAINER_ACCESS_KEY is retrived, optionally you can directly pass in a value.

Value

An AzureStore storage container object