extract_abundance_estimates.RdExtract parameter estimates from abundance BUGS model object
extract_abundance_estimates(abundance_inputs, model_object)a list of inputs for the abundance BUGS model, generated by running prepare_abundance_inputs()
the BUGS object produced by running fit_abundance_model_BUGS().
the site fit.
the run year fit.
A table with the format:
model_name
site
run_year
week_fit
location_fit
parameter
statistic
value
srjpedata_version
This function extracts parameter estimates from the abundance BUGS model and returns them in a tidy data frame format.