fit_pCap_model.RdFit pCap model
fit_pCap_model(input)a STANfit object with the pCap model fit.
This function prepares the data list for the abundance STAN model based on what the model name is.
Other Fit model:
fit_inseason_model(),
fit_passage_to_spawner_model(),
fit_stock_recruit_model(),
fit_survival_model()