fit_passage_to_spawner_model.RdThis functions take in a list of data required to run the Passage to Spawner STAN model. The function
will return the full fitted stanfit object.
See vignette("passage_to_spawner_submodel.Rmd", package = "SRJPEmodel") for more details.
fit_passage_to_spawner_model(data_inputs)A list object containing the following variables:
N number of years
observed_passage upstream passage for the associated years
observed_spawners observed spawner counts for the associated years. Redd counts for Battle and Clear Creeks.
percent_female Assumed sex ratio for the population and used to convert spawner counts to total population.
0.5 for redds, 1 for other spawner survey types.
environmental_covar the environmental covariate you want to run the model with.
ss_total total sum of squares.
average_upstream_passage average upstream passage across all years, used to forecast.
a STANfit model object (see details)
Other Fit model:
fit_inseason_model(),
fit_pCap_model(),
fit_stock_recruit_model(),
fit_survival_model()