generate_diagnostic_plot_juv.RdBT SPAS X diagnostic plots
generate_diagnostic_plot_juv(inputs, results_df)a list of inputs generated by running prepare_abundance_inputs()
a table of parameter estimates generated by running extract_abundance_estimates() or
by pulling and filtering from the database using get_most_recent_model_results().
A plot.
This function produces a plot with data and results of fitting the pCap and abundance models for a given site and run year.