generate_lt_pCap_Us.RdGenerate lt_pCap_U values from the pCap model object
generate_lt_pCap_Us(abundance_inputs, pcap_model_object)A list containing the inputs for the site-specific abundance model including
model_name, Nstrata, catch_flow, use_trib, Ntribs, Nmr, Nwmr, Nwomr, Uind_wMR, Uind_woMR,
ind_pCap. This is created by calling prepare_abundance_inputs().
a named list with the simulated lt_pCap_mu and lt_pCap_sd values for
Nstrata.
This function prepares the data list for the abundance STAN model based on what the model name is.