generate_results_plot_p2s.RdP2S results plots
generate_results_plot_p2s(p2s_inputs, con)inputs for the fit model, created by running prepare_P2S_inputs()
a connection to the database.
A plot showing observed and predicted spawners by year.
This function produces a plot with predicted spawners with uncertainty. for simple comparison.