generate_results_plot_sr.RdStock-recruit results plots
generate_results_plot_sr(sr_inputs, con)inputs for the fit model, created by running prepare_stock_recruit_inputs()
a connection to the database.
A plot.
This function produces a plot with observed and predicted recruits for simple comparison.