generate_survival_rate_plot.RdPlot smolt survival rate
generate_survival_rate_plot(survival_estimates)A table that is produced from running extract_survival_estimates().
A plot.
This function produces a plot showing the parameter estimates for SurvRelSac and SurvWoodSac, which
are survival rates for Release to Woodson Bridge and Woodson Bridge to Sacramento.