get_model_object.RdThis function retrieves the model object (.Rds file) from Azure Blob Storage using a keyword from the model run description or a model run ID.
get_model_object(
con,
model_component = "model_fit",
model_run_id = NULL,
keyword = NULL,
access_key = Sys.getenv("AZ_CONTAINER_ACCESS_KEY")
)A connection object to the database.
Select one of fit, input or plot object to pull.
An optional ID for a specific model run. If provided, it is used to find the corresponding blob URL. If neither keyword nor model_run_id is provided, the latest model run is used.
An optional string used to search for the model run description in the database. If provided, it is used to find the corresponding blob URL.
A string specifying the Azure storage access key with read permissions. By default, it retrieves from the environment variable AZ_CONTAINER_ACCESS_KEY.
The model object retrieved from the Azure Blob Storage. #' @examples