get_model_results_parameters.RdThis function retrieves the model parameter results from the JPE Database using a keyword(s) from the model run description or a model run ID.
get_model_results_parameters(con, keyword = NULL, model_run_id = NULL)A connection object to the database.
An optional string used to search for the model run description in the database. If provided, it is used to find the corresponding blob URL.
An optional ID for a specific model run. If provided, it is used to find the corresponding blob URL. If neither keyword nor model_run_id is provided, the latest model run is used.
A tibble containing model parameters.