model_pin_board.RdCreates a pin board for model data storage in Azure Blob Storage.
model_pin_board(storage_account, container, model_name, ...)The name of the Azure Storage account.
The name of the blob container within the storage account.
Additional arguments passed to setup_azure_blob_backend().
A pins board object connected to the specified Azure Blob Storage container.
if (FALSE) { # \dontrun{
board <- model_pin_board("my_storage_account", "my_container")
} # }