prepare_abundance_inputs.RdPrepare inputs for abundance model
prepare_abundance_inputs(
site,
run_year,
effort_adjust = c(T, F),
pcap_model_object,
input_catch_data = NULL,
input_efficiency_data = NULL
)site for which you want to fit the model
run year for which you want to fit the model
whether or not you want to use catch adjusted by effort.
Optional argument for weekly catch data.
Defaults to SRJPEdata::weekly_juvenile_abundance_catch_data. If
passed in, structure of data frame must match that of the default.
Optional argument for weekly efficiency data.
Defaults to SRJPEdata::SRJPEdata::weekly_juvenile_abundance_efficiency_data. If
passed in, structure of data frame must match that of the default.
a list:
abundance_inputs a list of data and inits for input into the abundance model.
model_name The version of the pCap logic to use for generating lt_pCap_U values. Either
all_mark_recap, missing_mark_recap, no_mark_recap, or no_mark_recap_no_trib.
site The site run.
run_year The run year.
weeks_fit The weeks fit for the abundance model
weeks_date Associated dates for the weeks fit for the abundance model.
lt_pCap_Us A list containing output of generate_lt_pCap_Us: containing values of
length Nstrata for lt_pCap_mu and lt_pCap_sd.
This function prepares data for input into an abundance model.