prepare_mainstem_pCap_data.RdPrepare mainstem inputs for abundance model
prepare_mainstem_pCap_data(mainstem_site)a named list, with each element containing the inputs required for one of the three mainstem sites. In this named list are
inputs a list of data and inits for input into the abundance model.
sites_fit The site the inputs were prepared for (either knights landing,
tisdale, or red bluff diversion dam).
This function is called within prepare_pCap_inputs()