prepare_pCap_inputs.RdPrepare inputs for pCap STAN model
prepare_pCap_inputs(
mainstem = c(FALSE, TRUE),
mainstem_site = NULL,
input_catch_data = NULL,
input_efficiency_data = NULL
)Whether or not you want to evaluate efficiency trials for a mainstem site
(knights landing, tisdale, and red bluff diversion dam) or for a tributary site. If FALSE,
the mark recapture dataset will be filtered to exclude those mainstem sites.
If you are fitting the model with mainstem == TRUE, you must supply a
mainstem site for which to prepare inputs. Can be either knights landing or tisdale.
Optional argument for weekly catch data.
Defaults to SRJPEdata::weekly_juvenile_abundance_catch_data. If
passed in, structure of data frame must match that of the default.
Optional argument for weekly efficiency data.
Defaults to SRJPEdata::SRJPEdata::weekly_juvenile_abundance_efficiency_data. If
passed in, structure of data frame must match that of the default.
a list:
pCap_inputs a list of data and inits for input into the pCap model.
sites_fit a list of site names associated with ind_trib.
This function prepares data for input into a pCap STAN model.
Other Prepare Model Inputs:
prepare_P2S_inputs(),
prepare_inseason_inputs(),
prepare_stock_recruit_inputs(),
prepare_survival_inputs()